@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.93_02';
+our $VERSION = '0.94_01';
 
 use POE;
 
@@ -63,7 +63,7 @@ sub spawn {
                     print "# $alias shutdown\n" if DEBUG;
                     my $k = $_[KERNEL];
 
-                    # Remove all timers
+                    # Remove all timers of our session
                     # and decrement session references
                     foreach my $alarm ($k->alarm_remove_all()) {
                         my ($name, $time, $t) = @$alarm;
@@ -142,11 +142,13 @@ sub add {
     my ( $session, $event, $iterator, @args ) = @_;
 
     # Remember only the session ID
-    $session = ref $session ? $session->ID : $session;
+    $session = $poe_kernel->alias_resolve($session) unless ref $session;
+    defined($session) or croak __PACKAGE__ . "->add: first arg must be an existing POE session ID or alias.";
+    $session = $session->ID;
 
     # We don't want to loose the session until the event has been handled
-    $poe_kernel->refcount_increment($session, $refcount_counter_name)
-      or croak __PACKAGE__ . "->add: first arg must be a POE session ID: $!";
+    $poe_kernel->refcount_increment($session, $refcount_counter_name) > 0
+      or croak __PACKAGE__ . "->add: first arg must be an existing POE session ID or alias: $!";
 
     ref $iterator && $iterator->isa('DateTime::Set')
       or croak __PACKAGE__ . "->add: third arg must be a DateTime::Set";
@@ -265,7 +267,7 @@ C<new()> is an alias for C<add()>.
 
 =head2 delete()
 
-Removes a schedule using the handle returned from C<->add()> or C<->new()>.
+Removes a schedule using the handle returned from C<add()> or C<new()>.
 
 B<DEPRECATED>: Schedules are now automatically deleted when they are not
 referenced anymore. So just setting the container variable to C<undef> will
@@ -275,7 +277,7 @@ delete the schedule.
 
 L<POE>, L<DateTime::Set>, L<POE::Component::Cron>.
 
-=head1 BUGS
+=head1 SUPPORT
 
 You can look for information at:
 
@@ -283,37 +285,41 @@ You can look for information at:
 
 =item * RT: CPAN's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-Schedule>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/POE-Component-Schedule>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-Schedule>:
+post bug report there.
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/p/POE-Component-Schedule>
+L<http://cpanratings.perl.org/p/POE-Component-Schedule>:
+if you use this distibution, please add comments on your experience for other
+users.
 
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/POE-Component-Schedule/>
 
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/POE-Component-Schedule>
+
 =back
 
 
 =head1 ACKNOWLEDGMENT & HISTORY
 
-This module was a friendly fork of L<POE::Component::Cron> to extract the generic
-parts and isolate the Cron specific code in order to reduce dependencies on
-other CPAN modules.
+This module was a friendly fork of L<POE::Component::Cron> to extract the
+generic parts and isolate the Cron specific code in order to reduce
+dependencies on other CPAN modules.
 
-See L<https://rt.cpan.org/Ticket/Display.html?id=44442>
+See L<https://rt.cpan.org/Ticket/Display.html?id=44442>.
 
 The orignal author of POE::Component::Cron is Chris Fedde.
 
-Most of the POE::Component::Schedule internals have since been rewritten in 0.91_01
-and we have now a complete test suite.
+POE::Component::Cron is now implemented as a class that inherits from
+POE::Component::Schedule.
 
-POE::Component::Cron is now implemented as a class that inherits from POE::Component::Schedule.
+Most of the POE::Component::Schedule internals have since been rewritten in
+0.91_01 and we have now a complete test suite.
 
 =head1 AUTHORS
 
@@ -329,9 +335,9 @@ POE::Component::Cron is now implemented as a class that inherits from POE::Compo
 
 =over 4
 
-=item Copyright E<copy> 2009-2010 Olivier MenguE<eacute>
+=item Copyright E<copy> 2009-2010 Olivier MenguE<eacute>.
 
-=item Copyright E<copy> 2007-2008 Chris Fedde
+=item Copyright E<copy> 2007-2008 Chris Fedde.
 
 =back
 
